@@ -1,7 +1,8 @@
 from gantry.dataset.main import (
-    init,
     create_dataset,
+    delete_dataset,
     get_dataset,
+    init,
     list_dataset_commits,
     list_datasets,
 )
@@ -12,4 +13,5 @@ __all__ = [
     "get_dataset",
     "list_dataset_commits",
     "list_datasets",
+    "delete_dataset",
 ]
