@@ -1,9 +1,12 @@
 import logging
 import uuid
-from typing import Dict, List, Optional
+from typing import Any, Dict, List, Optional
+
+from typeguard import typechecked
 
 from gantry.api_client import APIClient
 from gantry.dataset.gantry_dataset import GantryDataset
+from gantry.exceptions import DatasetNotFoundError, GantryRequestException
 
 logger = logging.getLogger(__name__)
 
@@ -23,6 +26,7 @@ class GantryDatasetClient:
         self.aws_region = aws_region
         self.workspace = workspace
 
+    @typechecked
     def create_dataset(self, name: str, model_id: Optional[uuid.UUID] = None) -> GantryDataset:
         """
         Create dataset
@@ -68,6 +72,7 @@ class GantryDatasetClient:
             workspace=self.workspace,
         )
 
+    @typechecked
     def get_dataset(self, name: str) -> GantryDataset:
         """
         Get dataset object
@@ -78,7 +83,12 @@ class GantryDatasetClient:
         Returns:
             GantryDataset
         """
-        res = self._api_client.request("GET", f"/api/v1/datasets/{name}", raise_for_status=True)
+        try:
+            res = self._api_client.request("GET", f"/api/v1/datasets/{name}", raise_for_status=True)
+        except GantryRequestException as e:
+            if e.status_code == 404:
+                raise DatasetNotFoundError(f'Could not find dataset with name "{name}"') from e
+            raise
 
         if res["data"]["disabled"]:
             logger.warning("This dataset is marked as deleted")
@@ -94,7 +104,8 @@ class GantryDatasetClient:
             workspace=self.workspace,
         )
 
-    def list_dataset_commits(self, name: str) -> List[Dict[str, str]]:
+    @typechecked
+    def list_dataset_commits(self, name: str) -> List[Dict[str, Any]]:
         """
         Show dataset commit history
 
@@ -108,7 +119,8 @@ class GantryDatasetClient:
 
         return dataset.list_commits()
 
-    def list_datasets(self, include_deleted=False) -> List[Dict[str, str]]:
+    @typechecked
+    def list_datasets(self, include_deleted: bool = False) -> List[Dict[str, Any]]:
         """
         List datasets
 
@@ -127,6 +139,7 @@ class GantryDatasetClient:
 
         return res["data"]
 
+    @typechecked
     def delete_dataset(self, name: str):
         """
         Delete dataset
