@@ -9,13 +9,19 @@ import uuid
 from collections import defaultdict
 from dataclasses import asdict, dataclass
 from pathlib import Path
-from typing import IO, Callable, Dict, List, Optional
+from typing import IO, Any, Callable, Dict, List, Optional, Union
 
 import pandas as pd
+from typeguard import typechecked
 
 from gantry.api_client import APIClient
 from gantry.dataset import constants
-from gantry.exceptions import DatasetDeletedException, GantryRequestException
+from gantry.exceptions import (
+    DatasetCommitNotFoundError,
+    DatasetDeletedException,
+    GantryRequestException,
+    DatasetNotFoundError,
+)
 from gantry.utils import (
     download_file_from_url,
     get_files_checksum,
@@ -51,6 +57,24 @@ def _ensure_not_deleted(func: Callable) -> Callable:
     return wrapper
 
 
+def _ensure_dataset_exist_locally(func: Callable) -> Callable:
+    """
+    Decorator to ensure dataset exist locally, if not will warn the user to download the dataset.
+    """
+
+    @functools.wraps(func)
+    def wrapper(self, *args, **kwargs):
+        if not Path(self._get_file_path(constants.DATASET_MANIFEST_FILE)).exists():
+            raise DatasetNotFoundError(
+                f"Can't find dataset {self.dataset_name} locally, please run sync()"
+                f"to download the dataset into your local workspace."
+            )
+
+        return func(self, *args, **kwargs)
+
+    return wrapper
+
+
 @dataclass
 class DatasetFileInfo:
     file_name: str
@@ -89,18 +113,19 @@ class GantryDataset:
         self._dataset_s3_prefix = dataset_s3_prefix
         self._aws_region = aws_region
 
-    def list_commits(self) -> List[Dict[str, str]]:
+    def list_commits(self) -> List[Dict[str, Any]]:
         """
         Get dataset commits history
 
         Returns:
-            List[Dict[str, str]]: dataset commits sorted from latest to earlist.
+            List[Dict[str, Any]]: dataset commits sorted from latest to earliest.
         """
         response = self._api_client.request(
             "GET", f"/api/v1/datasets/{self._dataset_id}/commits", raise_for_status=True
         )
         return response["data"]
 
+    @_ensure_dataset_exist_locally
     def get_diff(self) -> Dict[str, List[str]]:
         """
         Get local changes which hasn't been committed
@@ -111,6 +136,7 @@ class GantryDataset:
                 "deleted_files": List[str],
             }
         """
+
         diff = self._get_diff()
         return {
             constants.NEW_FILES: [f for f, _ in diff[constants.NEW_FILES]],
@@ -118,8 +144,10 @@ class GantryDataset:
             constants.DELETED_FILES: [f for f, _ in diff[constants.DELETED_FILES]],
         }
 
+    @typechecked
+    @_ensure_dataset_exist_locally
     @_ensure_not_deleted
-    def create_commit(self, message: str) -> Dict[str, str]:
+    def create_commit(self, message: str) -> Dict[str, Any]:
         """
         This method will compute the difference between the current commit and the local directory,
         upload new files and modified files to dataset repo. After that we will update
@@ -181,13 +209,14 @@ class GantryDataset:
 
         return commit_info
 
+    @typechecked
     @_ensure_not_deleted
     def add_file(
         self,
         file: IO,
         filename: Optional[str] = None,
         commit_message: Optional[str] = None,
-    ) -> Dict[str, str]:
+    ) -> Dict[str, Any]:
         """
         This method will upload a file (such as a file opened with ``open()``) to the dataset in a
         new commit. Does not rely on the user having the dataset synced, nor does it cause the
@@ -210,13 +239,14 @@ class GantryDataset:
 
         return self._add_single_file(file, name, commit_message)
 
+    @typechecked
     @_ensure_not_deleted
     def add_tabular_file(
         self,
         file: IO,
         filename: Optional[str] = None,
         commit_message: Optional[str] = None,
-    ) -> Dict[str, str]:
+    ) -> Dict[str, Any]:
         """
         This method will upload a csv file (such as a csv file opened with ``open()``) to the
         tabular_manifests of the dataset in a new commit. Does not rely on the user having the
@@ -242,13 +272,14 @@ class GantryDataset:
 
         return self._add_single_file(file, name, commit_message)
 
+    @typechecked
     @_ensure_not_deleted
     def add_dataframe(
         self,
         dataframe: pd.DataFrame,
         csvname: Optional[str] = None,
         commit_message: Optional[str] = None,
-    ) -> Dict[str, str]:
+    ) -> Dict[str, Any]:
         """
         This method will upload a pandas DataFrame as a new commit in the form of a csv. Does not
         rely on the user having the dataset synced, nor does it cause the dataset to sync after the
@@ -279,8 +310,9 @@ class GantryDataset:
 
         return self._add_single_file(file, name, commit_message)
 
+    @typechecked
     @_ensure_not_deleted
-    def rollback(self, commit_id: str) -> Dict[str, str]:
+    def rollback(self, commit_id: Union[str, uuid.UUID]) -> Dict[str, Any]:
         """
         Roll back the dataset to a previous version based on commit id, then sync the local dataset
         folder to the newly created commit.
@@ -309,8 +341,9 @@ class GantryDataset:
 
         return commit_info
 
+    @typechecked
     @_ensure_not_deleted
-    def sync(self, commit_id: Optional[str] = None) -> Dict[str, str]:
+    def sync(self, commit_id: Optional[Union[str, uuid.UUID]] = None) -> Dict[str, Any]:
         """
         Sync local dataset folder based on a commit id. If commit_id was not provided, will sync
         based on the latest commit.
@@ -360,7 +393,8 @@ class GantryDataset:
         logger.info(f"Dataset {self.dataset_name} has been deleted")
         return
 
-    def get_commit(self, commit_id: str) -> Dict[str, str]:
+    @typechecked
+    def get_commit(self, commit_id: Union[str, uuid.UUID]) -> Dict[str, Any]:
         """
         Get commit details
 
@@ -369,12 +403,21 @@ class GantryDataset:
         Returns:
             Commit information
         """
-        resp = self._api_client.request(
-            "GET", f"/api/v1/datasets/{self._dataset_id}/commits/{commit_id}", raise_for_status=True
-        )
+        try:
+            resp = self._api_client.request(
+                "GET",
+                f"/api/v1/datasets/{self._dataset_id}/commits/{commit_id}",
+                raise_for_status=True,
+            )
+        except GantryRequestException as e:
+            if e.status_code == 404:
+                raise DatasetCommitNotFoundError(
+                    f"Could not find dataset commit with id {commit_id}"
+                ) from e
+            raise
         return resp["data"]
 
-    def get_latest_commit(self) -> Dict[str, str]:
+    def get_latest_commit(self) -> Dict[str, Any]:
         """
         Get latest commit details
 
@@ -576,11 +619,11 @@ class GantryDataset:
         _, obj_key = parse_s3_path(s3_url)
         return obj_key
 
-    def _update_head(self, commit_info: Dict[str, str]):
+    def _update_head(self, commit_info: Dict[str, Any]):
         with open(self._get_file_path(constants.DATASET_HEAD_FILE), "w") as f:
             json.dump(commit_info, f)
 
-    def _get_current_commit(self) -> Dict[str, str]:
+    def _get_current_commit(self) -> Dict[str, Any]:
         with open(self._get_file_path(constants.DATASET_HEAD_FILE), "r") as f:
             return json.load(f)
 
