@@ -92,3 +92,19 @@ class DatasetDeletedException(GantryException):
     """
 
     pass
+
+
+class DatasetCommitNotFoundError(GantryException):
+    """
+    Raised when a specific requested dataset commit is not found
+    """
+
+    pass
+
+
+class DatasetNotFoundError(GantryException):
+    """
+    Raised when a specific requested dataset is not found
+    """
+
+    pass
