@@ -1,14 +1,13 @@
 import datetime
 import logging
-import random
 import uuid
 from typing import Any, Dict, Iterable, List, Optional, Tuple, Union
 
 from gantry.exceptions import GantryLoggingException
 from gantry.logger.constants import BatchType, Delimiter, UploadFileType
 from gantry.logger.types import DataLink, DataLinkElement
-from gantry.logger.utils import _check_sample_rate, get_file_linecount
-from gantry.utils import check_event_time_in_future, compute_feedback_id
+from gantry.logger.utils import get_file_linecount
+from gantry.utils import check_event_time_in_future
 from gantry.validators import validate_logged_field_datatype
 
 logger = logging.getLogger(__name__)
@@ -22,22 +21,14 @@ def _build_prediction_and_feedback_events(
     inputs: List[dict],
     outputs: Union[List[dict], List[Any]],
     feedbacks: List[dict],
+    join_keys: List[str],
     version: Optional[Union[str, int]] = None,
-    feedback_keys: Optional[List[str]] = None,
     ignore_inputs: Optional[List[str]] = None,
-    sample_rate: float = 1.0,
     tags: Optional[Dict[str, str]] = None,
 ):
     """Build prediction and feedback events for log_records"""
-    _check_sample_rate(sample_rate)
-
     events = []
     for idx, timestamp in timestamp_idx:
-        if random.random() > sample_rate:
-            continue
-
-        feedback_id = {k: inputs[idx][k] for k in (feedback_keys or [])}
-
         event = {}
 
         event.update(
@@ -47,10 +38,9 @@ def _build_prediction_and_feedback_events(
                 inputs[idx],
                 outputs[idx],
                 application,
+                join_keys[idx],
                 version,
-                feedback_keys,
                 ignore_inputs,
-                feedback_id=None,
                 custom_timestamp=timestamp,
                 tags=tags,
             )
@@ -59,7 +49,7 @@ def _build_prediction_and_feedback_events(
         feedback_event = _build_feedback_event(
             context,
             application,
-            feedback_id,
+            join_keys[idx],
             feedbacks[idx],
             version,  # type: ignore
             timestamp,
@@ -107,7 +97,7 @@ def _enrich_events_with_batch_id(events, batch_id):
 def _build_feedback_event(
     context: dict,
     application: str,
-    feedback_id: Union[str, dict],
+    join_key: str,
     feedback: dict,
     feedback_version: Optional[Union[str, int]] = None,
     timestamp: Optional[datetime.datetime] = None,
@@ -119,10 +109,6 @@ def _build_feedback_event(
     metadata: Dict[str, Any] = {}
     metadata.update(context)
     metadata.update({"func_name": application, "feedback_version": feedback_version})
-    if isinstance(feedback_id, str):
-        computed_feedback_id = feedback_id
-    else:
-        computed_feedback_id = compute_feedback_id(feedback_id, list(feedback_id.keys()))
 
     log_time = datetime.datetime.utcnow()
     event_time = timestamp if timestamp else log_time
@@ -135,7 +121,6 @@ def _build_feedback_event(
     log_time_str, event_time_str = log_time.isoformat(), event_time.isoformat()
 
     validate_logged_field_datatype(feedback, paths=["feedback"])
-    validate_logged_field_datatype(feedback_id, paths=["feedback_id"])
     validate_logged_field_datatype(event_time_str, paths=["timestamp"])
 
     return {
@@ -143,9 +128,8 @@ def _build_feedback_event(
         "timestamp": event_time_str,
         "log_timestamp": log_time_str,
         "metadata": metadata,
-        "feedback_id_inputs": feedback_id,
         "feedback": feedback,
-        "feedback_id": computed_feedback_id,
+        "feedback_id": join_key,
         "batch_id": batch_id,
     }
 
@@ -158,22 +142,13 @@ def _build_prediction_events(
     context: Dict[str, str],
     environment: str,
     version: Optional[Union[str, int]],
-    feedback_keys: Optional[List[str]] = None,
+    join_keys: List[str],
     ignore_inputs: Optional[List[str]] = None,
-    feedback_ids: Optional[Union[List[str], List[dict]]] = None,
-    sample_rate: float = 1.0,
     batch_id: Optional[str] = None,
     tags: Optional[Dict[str, str]] = None,
 ):
-    _check_sample_rate(sample_rate)
-
     events = []
     for idx, timestamp in timestamp_idx:
-        if random.random() > sample_rate:
-            continue
-
-        feedback_id = feedback_ids[idx] if feedback_ids else None
-
         events.append(
             _build_prediction_event(
                 context,
@@ -181,11 +156,10 @@ def _build_prediction_events(
                 inputs[idx],
                 outputs[idx],
                 application,
+                join_keys[idx],
                 version,
-                feedback_keys,
                 ignore_inputs,
                 batch_id=batch_id,
-                feedback_id=feedback_id,
                 custom_timestamp=timestamp,
                 tags=tags,
             )
@@ -200,11 +174,10 @@ def _build_prediction_event(
     inputs: Dict,
     outputs: Any,
     application: str,
+    join_key: str,
     version: Optional[Union[int, str]],
-    feedback_keys: Optional[List[str]],
     ignore_inputs: Optional[List[str]],
     batch_id: Optional[str] = None,
-    feedback_id: Optional[Union[str, dict]] = None,
     tags: Optional[Dict[str, str]] = None,
     custom_timestamp: Optional[datetime.datetime] = None,
 ):
@@ -214,28 +187,12 @@ def _build_prediction_event(
         {
             "func_name": application,
             "version": version,
-            "feedback_keys": feedback_keys,
+            "feedback_keys": None,  # TODO -> see if this can be removed
             "ignore_inputs": ignore_inputs,
-            "provided_feedback_id": feedback_id,
         }
     )
     inputs = dict(inputs)  # make a copy so we can pop keys safely
 
-    if feedback_id:
-        if feedback_keys:
-            raise GantryLoggingException(
-                "Cannot specify feedback_id and feedback_keys at same time."
-            )
-
-        if isinstance(feedback_id, str):
-            # Set the feedback_id directly from the given string.
-            computed_feedback_id = feedback_id
-        else:
-            # Compute feedback_id just from provided feedback_id dictionary
-            computed_feedback_id = compute_feedback_id(feedback_id, list(feedback_id.keys()))
-    else:
-        computed_feedback_id = compute_feedback_id(inputs, feedback_keys)
-
     if ignore_inputs:
         for ignore in ignore_inputs:
             inputs.pop(ignore, None)
@@ -264,7 +221,7 @@ def _build_prediction_event(
         "metadata": metadata,
         "inputs": inputs,
         "outputs": outputs,
-        "feedback_id": computed_feedback_id,
+        "feedback_id": join_key,
         "tags": processed_tags,
         "batch_id": batch_id,
     }
