@@ -142,11 +142,6 @@ def _init(
         logger_obj.warning("Gantry services won't receive traffic. Check if API Key is valid")
 
 
-@_client_alias
-def instrument(*args, **kwargs):
-    return _CLIENT.instrument(*args, **kwargs)
-
-
 @_client_alias
 def ping():
     return _CLIENT.ping()
@@ -157,16 +152,6 @@ def ready():
     return _CLIENT.ready()
 
 
-@_client_alias
-def log_feedback_event(*args, **kwargs):
-    return _CLIENT.log_feedback_event(*args, **kwargs)
-
-
-@_client_alias
-def log_feedback(*args, **kwargs):
-    return _CLIENT.log_feedback(*args, **kwargs)
-
-
 @_client_alias
 def log_file(
     application: str,
@@ -196,6 +181,7 @@ def log_record(
     timestamp: Optional[datetime.datetime] = None,
     sample_rate: float = 1.0,
     tags: Optional[Dict[str, str]] = None,
+    join_key: Optional[str] = None,
 ) -> None:
     return _CLIENT.log_record(**locals())  # type: ignore[union-attr]
 
@@ -215,20 +201,11 @@ def log_records(
     sample_rate: float = 1.0,
     as_batch: bool = False,
     tags: Optional[Dict[str, str]] = None,
+    join_keys: Optional[List[str]] = None,
 ) -> None:
     return _CLIENT.log_records(**locals())  # type: ignore[union-attr]
 
 
-@_client_alias
-def log_prediction_event(*args, **kwargs):
-    return _CLIENT.log_prediction_event(*args, **kwargs)
-
-
-@_client_alias
-def log_predictions(*args, **kwargs):
-    return _CLIENT.log_predictions(*args, **kwargs)
-
-
 def get_client():
     return _CLIENT
 
