@@ -8,15 +8,10 @@ from halo import Halo
 from tabulate import tabulate
 
 from gantry.api_client import APIClient
-from gantry.query.core.constants import STATUS_PARAM
 from gantry.query.core.dataframe import GantryDataFrame
 from gantry.query.core.distance import GantryDistance
 from gantry.query.core.metric import GantryMetric
-from gantry.query.core.utils import (
-    check_response,
-    get_application_node_id,
-    get_application_views,
-)
+from gantry.query.core.utils import get_application_node_id, get_application_views
 
 logger = logging.getLogger(__name__)
 
@@ -37,11 +32,10 @@ class GantryQuery:
             List of application names that are stored in gantry.
         """
         query_params = {"limit": 10}
-        response = self._api_client.request("GET", "/api/v1/models", params=query_params)
-        check_response(response)
-        return [
-            application for application in response["data"].keys() if application != STATUS_PARAM
-        ]
+        response = self._api_client.request(
+            "GET", "/api/v1/models", params=query_params, raise_for_status=True
+        )
+        return list(response["data"].keys())
 
     def list_application_versions(self, application: str) -> List[str]:
         """
@@ -56,9 +50,11 @@ class GantryQuery:
             List of versions for |application| that are stored in gantry.
         """
         version_response = self._api_client.request(
-            "GET", "/api/v1/models/" + application, params={"include_names": True}
+            "GET",
+            "/api/v1/models/" + application,
+            params={"include_names": True},
+            raise_for_status=True,
         )
-        check_response(version_response)
         data = version_response["data"]
         return [version_dict["version"] for version_dict in data["versions"]]
 
@@ -71,8 +67,9 @@ class GantryQuery:
         Returns:
             List of environments
         """
-        response = self._api_client.request("GET", "/api/v1/models/" + application)
-        check_response(response)
+        response = self._api_client.request(
+            "GET", "/api/v1/models/" + application, raise_for_status=True
+        )
         return response["data"]["environments"]
 
     def query(
@@ -309,8 +306,7 @@ class GantryQuery:
         if not (duration or start_time or end_time):
             raise ValueError("Need to provide duration or start_time/end_time")
 
-        response = self._api_client.request("POST", "/api/v1/views", json=data)
-        check_response(response)
+        self._api_client.request("POST", "/api/v1/views", json=data, raise_for_status=True)
         return None
 
     def list_application_views(
