@@ -3,7 +3,6 @@ import datetime
 import json
 from collections import defaultdict
 from distutils.util import strtobool
-
 from typing import Any, Dict, List, Optional, Tuple, Union
 
 import dateparser
@@ -17,7 +16,7 @@ from gantry.query.core.constants import (
     SCHEMA_TYPES,
     TIMEZONE,
 )
-from gantry.query.core.utils import _build_empty_df_with_schema, check_response
+from gantry.query.core.utils import _build_empty_df_with_schema
 
 ORDER_ASCENDING = "ascending"
 ORDER_DESCENDING = "descending"
@@ -54,6 +53,7 @@ def _get_raw_data(api_client: APIClient, query_info: QueryInfo, dumped_json_data
         json=json.loads(
             dumped_json_data
         ),  # Need to receive dumped data because json dicts are not hashable
+        raise_for_status=True,
     )
 
 
@@ -65,8 +65,8 @@ def _get_metadata(api_client, application_name, frozen_query_params):
         "GET",
         "/api/v1/models/" + application_name + "/schemas",
         params=query_params,
+        raise_for_status=True,
     )
-    check_response(response)
     return response["data"]
 
 
@@ -278,7 +278,6 @@ class GantryQueryFrame(object):
         has_next = True
         while has_next:
             response = _get_raw_data(self.api_client, self.query_info, json.dumps(json_data))
-            check_response(response)
             events.extend(response["events"])
             to_fetch = n or response["metadata"]["count"]
             has_next = response["metadata"]["has_next"] and (len(events) < to_fetch)
