@@ -2,16 +2,28 @@ import functools
 from datetime import datetime
 from inspect import getcallargs, getfullargspec
 from typing import Dict, Optional, Tuple, Union, cast
+
 import dateparser
 import isodate
 import pandas as pd
+
 from gantry.api_client import APIClient
 
 
-def same_size(*params):
-    # Use this decorator to prevent running methods over iterables that are different sizes.
-    # For example, if 'some_method(s1, s2, s3)' need s1/s2/s3 to be same size then
-    # it can be decorated with '@same_size("s1", "s2", "s3")'.
+def same_size(*params: str, allow_empty: bool = False):
+    """
+    Use this decorator to prevent running methods over iterables that are different sizes.
+    For example, if 'some_method(s1, s2, s3)' need s1/s2/s3 to be same size then
+    it can be decorated with '@same_size("s1", "s2", "s3")'.
+
+    Args:
+        *params (List[str]): Name of parameters that will be passed to the decorated
+            method
+        allow_empty (bool, defaults to False): In case False, empty Parameters
+            (with length of 0) will fail the check.
+
+    """
+
     def decorator(method):
         fullargs = getfullargspec(method).args
         if not all(map(lambda x: x in fullargs, params)):
@@ -24,7 +36,12 @@ def same_size(*params):
         @functools.wraps(method)
         def wrapper(*args, **kwargs):
             provided_params = getcallargs(method, *args, **kwargs)
-            sizes = {param: len(provided_params[param]) for param in params}
+            sizes = {}
+            for param in params:
+                size = len(provided_params[param])
+                if not allow_empty and len(provided_params[param]) == 0:
+                    raise ValueError(f"Parameter '{param}' has size 0. This is not allowed.")
+                sizes[param] = size
             if len(set(sizes.values())) != 1:
                 raise ValueError(
                     f"Size mismatch on inputs: {sizes}. "
@@ -73,7 +90,7 @@ def get_application_views(
     views = response["data"]
 
     if environment:
-        views = list(filter(lambda view: view["tag_filters"]["env"] == environment, views))
+        views = list(filter(lambda view: view["tag_filters"].get("env") == environment, views))
 
     return views
 
