@@ -1,7 +1,7 @@
 import inspect
 from typing import Optional
 
-from gantry.exceptions import GantryException
+from gantry.exceptions import ClientNotInitialized
 from gantry.query.client import GantryQuery
 from gantry.query.core.distance import GantryDistance
 from gantry.query.core.metric import GantryMetric
@@ -31,4 +31,4 @@ def _query_alias(f):
 
 def validate_init():
     if _Query is None:
-        raise GantryException("Query functionality has not been initialized with a backend.")
+        raise ClientNotInitialized()
