@@ -1,5 +1,6 @@
 import datetime
 import os
+import warnings
 from typing import Dict, List, Optional, Union
 from urllib.parse import urlparse
 
@@ -11,10 +12,13 @@ from gantry.query.core.dataframe import GantryDataFrame  # noqa
 from gantry.query.globals import _query_alias, validate_init
 
 
-def init(backend: str = PROD_API_URL, api_key: Optional[str] = None):
+def init(api_key: Optional[str] = None):
     """
     Initialize the Query functionality. Initialization should happen before any Query call.
 
+    WARNING: this method will be deprecated soon, Use global `init` to intialize query
+    functionality, as shown below.
+
     Example:
 
     .. code-block:: python
@@ -24,9 +28,16 @@ def init(backend: str = PROD_API_URL, api_key: Optional[str] = None):
        gquery.init(api_key="foobar")
 
     Args:
-        backend (str): The backend URL. Defaults to the Gantry production URL.
         api_key (str): The API key. Users can fetch the API key from the dashboard.
     """
+    warnings.warn(
+        "This initialization method will be deprecated soon, use global gantry.init instead"
+    )
+    _init(api_key)
+
+
+def _init(api_key: Optional[str] = None):
+    backend = os.environ.get("GANTRY_LOGS_LOCATION", PROD_API_URL)
     parsed_origin = urlparse(backend)
     if parsed_origin.scheme not in ("http", "https"):
         raise ValueError(
@@ -96,42 +107,6 @@ def query(
     return globals._Query.query(**locals())  # type: ignore[union-attr]
 
 
-@_query_alias
-def get_current_feedback_schema(application: str):
-    validate_init()
-    return globals._Query.get_current_feedback_schema(**locals())  # type: ignore[union-attr]
-
-
-@_query_alias
-def update_feedback_schema(application, feedback_fields: List[Dict[str, str]], create: bool = True):
-    validate_init()
-    return globals._Query.update_feedback_schema(**locals())  # type: ignore[union-attr]
-
-
-@_query_alias
-def add_feedback_field(application: str, feedback_field: Dict[str, str]) -> int:
-    validate_init()
-    return globals._Query.add_feedback_field(**locals())  # type: ignore[union-attr]
-
-
-@_query_alias
-def get_current_metric_schema(application: str):
-    validate_init()
-    return globals._Query.get_current_metric_schema(**locals())  # type: ignore[union-attr]
-
-
-@_query_alias
-def update_metric_schema(application: str, metrics: List[dict], create: bool = True):
-    validate_init()
-    return globals._Query.update_metric_schema(**locals())  # type: ignore[union-attr]
-
-
-@_query_alias
-def add_metric(application: str, metric: dict) -> int:
-    validate_init()
-    return globals._Query.add_metric(**locals())  # type: ignore[union-attr]
-
-
 @_query_alias
 def list_application_views(
     application: str,
