@@ -7,6 +7,9 @@ from gantry.query.metric.main import (  # # noqa: F401
     r2_score,
     recall_score,
     roc_auc_score,
+    percent_null,
+    percent_false,
+    percent_true,
 )
 
 __all__ = [
@@ -18,4 +21,7 @@ __all__ = [
     "precision_score",
     "recall_score",
     "roc_auc_score",
+    "percent_null",
+    "percent_false",
+    "percent_true",
 ]
