@@ -3,6 +3,7 @@ import responses
 
 from gantry.api_client import APIClient
 from gantry.dataset.client import GantryDatasetClient
+from gantry.exceptions import DatasetNotFoundError, GantryRequestException
 
 from .conftest import (
     AWS_REGION,
@@ -71,6 +72,25 @@ def test_get_dataset(test_client, test_dataset):
         assert dataset.workspace == "."
 
 
+@pytest.mark.parametrize(
+    ("status_code", "expected_error"),
+    [(404, DatasetNotFoundError), (500, GantryRequestException)],
+)
+def test_get_dataset_error(test_client, status_code, expected_error):
+    """
+    Test get dataset error
+    """
+    with responses.RequestsMock() as resp:
+        resp.add(
+            resp.GET,
+            f"{HOST}/api/v1/datasets/{DATASET_NAME}",
+            status=status_code,
+            headers={"Content-Type": "application/json"},
+        )
+        with pytest.raises(expected_error):
+            test_client.get_dataset(DATASET_NAME)
+
+
 def test_dataset_commits(test_client, test_dataset, commit_history):
     """
     Test get dataset commits
