@@ -9,9 +9,15 @@ from mock import patch
 from responses import matchers
 
 from gantry.api_client import APIClient
+from gantry.utils import list_all_files
 from gantry.dataset.constants import DELETED_FILES, MODIFIED_FILES, NEW_FILES
 from gantry.dataset.gantry_dataset import DatasetFileInfo, GantryDataset
-from gantry.exceptions import GantryException
+from gantry.exceptions import (
+    DatasetCommitNotFoundError,
+    GantryException,
+    GantryRequestException,
+    DatasetNotFoundError,
+)
 
 from .conftest import (
     AWS_REGION,
@@ -87,6 +93,23 @@ def test_get_commit(gantry_dataset_obj, commit_history):
         assert commit == expected_commit
 
 
+@pytest.mark.parametrize(
+    ("status_code", "expected_error"),
+    [(404, DatasetCommitNotFoundError), (500, GantryRequestException)],
+)
+def test_get_commit_error(gantry_dataset_obj, commit_history, status_code, expected_error):
+    commit_id = commit_history[0]["id"]
+    with responses.RequestsMock() as resp:
+        resp.add(
+            resp.GET,
+            f"{HOST}/api/v1/datasets/{DATASET_ID}/commits/{commit_id}",
+            status=status_code,
+            headers={"Content-Type": "application/json"},
+        )
+        with pytest.raises(expected_error):
+            gantry_dataset_obj.get_commit(commit_id)
+
+
 def test_get_latest_commit(gantry_dataset_obj, commit_history):
     """
     Test get latest commit
@@ -120,6 +143,26 @@ def test_get_diff(gantry_dataset_obj):
     assert diff[DELETED_FILES] == ["README.md"]
 
 
+def test_get_diff_not_exist(gantry_dataset_obj):
+    """
+    Test get diff without download the dataset
+    """
+    # overwrite the dataset name
+    gantry_dataset_obj.dataset_name = "dataset_not_exist"
+    with pytest.raises(DatasetNotFoundError):
+        gantry_dataset_obj.get_diff()
+
+
+def test_create_commit_without_download(gantry_dataset_obj):
+    """
+    Test create commit when no dataset downloaded locally
+    """
+    # overwrite the dataset name
+    gantry_dataset_obj.dataset_name = "dataset_not_exist"
+    with pytest.raises(DatasetNotFoundError):
+        gantry_dataset_obj.create_commit("test commit")
+
+
 def setup_resp_for_deleted_check(resp, is_deleted=False, dataset_name=DATASET_NAME):
     resp.add(
         resp.GET,
@@ -354,8 +397,8 @@ def test_sync_dataset(commit_id, datadir, gantry_dataset_obj, commit_history):
         with open(datadir / "show_diff_dataset/.dataset_metadata/HEAD") as f:
             assert json.load(f) == commit_json
 
-        assert not any(Path(datadir / "show_diff_dataset/tabular_manifests").iterdir())
-        assert not any(Path(datadir / "show_diff_dataset/artifacts").iterdir())
+        assert not list_all_files(Path(datadir / "show_diff_dataset/tabular_manifests"))
+        assert not list_all_files(Path(datadir / "show_diff_dataset/artifacts"))
 
 
 def test_to_jsonl():
