@@ -55,11 +55,13 @@ def test_runs_on_valid(supported, valid):
     assert f(mock.Mock(dtype=valid))
 
 
+l_0 = []
 l_1 = list(range(1))
 l_10 = list(range(10))
 l_100 = list(range(100))
 
 
+@pytest.mark.parametrize("allow_empty", [False, True])
 @pytest.mark.parametrize(
     ["args", "kwargs"],
     [
@@ -68,8 +70,8 @@ l_100 = list(range(100))
         ([], {"s1": l_10, "s3": l_10, "s2": l_10}),
     ],
 )
-def test_same_size_valid(args, kwargs):
-    dec = same_size("s1", "s2", "s3")
+def test_same_size_valid(args, kwargs, allow_empty):
+    dec = same_size("s1", "s2", "s3", allow_empty=allow_empty)
     f = dec(lambda s1, s2, s3: True)
     assert f(*args, **kwargs)
 
@@ -77,14 +79,48 @@ def test_same_size_valid(args, kwargs):
 @pytest.mark.parametrize(
     ["args", "kwargs"],
     [
-        ([l_10, l_100], {"s3": l_10}),
-        ([l_10], {"s3": l_100, "s2": l_100}),
-        ([], {"s1": l_10, "s3": l_100, "s2": l_10}),
-        ([], {"s1": l_10, "s3": l_100, "s2": l_1}),
+        ([l_0, l_0], {"s3": l_0}),
+        ([l_0], {"s3": l_0, "s2": l_0}),
+        ([], {"s1": l_0, "s3": l_0, "s2": l_0}),
     ],
 )
-def test_same_size_error(args, kwargs):
-    dec = same_size("s1", "s2", "s3")
+def test_same_size_valid_allow_empty(args, kwargs):
+    dec = same_size("s1", "s2", "s3", allow_empty=True)
+    f = dec(lambda s1, s2, s3: True)
+    assert f(*args, **kwargs)
+
+
+@pytest.mark.parametrize("allow_empty_kwarg", [{}, {"allow_empty": False}])  # Test default value
+@pytest.mark.parametrize(
+    ["args", "kwargs"],
+    [
+        ([l_0, l_0], {"s3": l_0}),
+        ([l_0], {"s3": l_0, "s2": l_0}),
+        ([], {"s1": l_0, "s3": l_0, "s2": l_0}),
+    ],
+)
+def test_same_size_valid_not_allow_empty(args, kwargs, allow_empty_kwarg):
+    dec = same_size("s1", "s2", "s3", **allow_empty_kwarg)
+    f = dec(lambda s1, s2, s3: True)
+    with pytest.raises(ValueError):
+        f(*args, **kwargs)
+
+
+@pytest.mark.parametrize("allow_empty", [False, True])
+@pytest.mark.parametrize(
+    ["args", "kwargs"],
+    [
+        ([l_10, l_100], {"s3": l_10}),
+        ([l_10], {"s3": l_100, "s2": l_100}),
+        ([l_0], {"s3": l_100, "s2": l_100}),
+        ([], {"s1": l_10, "s3": l_100, "s2": l_10}),
+        ([], {"s1": l_10, "s3": l_100, "s2": l_1}),
+        ([], {"s1": l_0, "s3": l_100, "s2": l_10}),
+        ([], {"s1": l_0, "s3": l_100, "s2": l_0}),
+    ],
+)
+def test_same_size_not_same_size_error(args, kwargs, allow_empty):
+    dec = same_size("s1", "s2", "s3", allow_empty=allow_empty)
     f = dec(lambda s1, s2, s3: True)
     with pytest.raises(ValueError):
         f(*args, **kwargs)
